Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/graphql/mutations/design_management/delete_spec.rb')
-rw-r--r--spec/graphql/mutations/design_management/delete_spec.rb45
1 files changed, 23 insertions, 22 deletions
diff --git a/spec/graphql/mutations/design_management/delete_spec.rb b/spec/graphql/mutations/design_management/delete_spec.rb
index 9a2efb61e55..1b78529fbc7 100644
--- a/spec/graphql/mutations/design_management/delete_spec.rb
+++ b/spec/graphql/mutations/design_management/delete_spec.rb
@@ -90,7 +90,7 @@ RSpec.describe Mutations::DesignManagement::Delete do
allow(Gitlab::Tracking).to receive(:event) # rubocop:disable RSpec/ExpectGitlabTracking
filenames.each(&:present?) # ignore setup
- # Queries: as of 2022-08-30
+ # Queries: as of 2022-09-08
# -------------
# 01. routing query
# 02. policy query: find namespace by type and id
@@ -101,30 +101,31 @@ RSpec.describe Mutations::DesignManagement::Delete do
# 08. find project by id
# 09. find namespace by id
# 10. find group namespace by id
- # 11. project.authorizations for user (same query as 5)
- # 12. find user by id
- # 13. project.project_features (same query as 3)
- # 14. project.authorizations for user (same query as 5)
- # 15. current designs by filename and issue
- # 16, 17 project.authorizations for user (same query as 5)
- # 18. find design_management_repository for project
- # 19. find route by id and source_type
+ # 11. policy query: find namespace by id (same query as 3)
+ # 12. project.authorizations for user (same query as 5)
+ # 13. find user by id
+ # 14. project.project_features (same query as 3)
+ # 15. project.authorizations for user (same query as 5)
+ # 16. current designs by filename and issue
+ # 17, 18 project.authorizations for user (same query as 5)
+ # 19. find design_management_repository for project
+ # 20. find route by id and source_type
# ------------- our queries are below:
- # 20. start transaction
- # 21. create version with sha and issue
- # 22. create design-version links
- # 23. validate version.actions.present?
- # 24. validate version.sha is unique
- # 25. validate version.issue.present?
- # 26. leave transaction
- # 27. find project by id (same query as 8)
- # 28. find namespace by id (same query as 9)
- # 29. find project by id (same query as 8)
+ # 21. start transaction
+ # 22. create version with sha and issue
+ # 23. create design-version links
+ # 24. validate version.actions.present?
+ # 25. validate version.sha is unique
+ # 26. validate version.issue.present?
+ # 27. leave transaction
+ # 28. find project by id (same query as 8)
+ # 29. find namespace by id (same query as 9)
# 30. find project by id (same query as 8)
# 31. create event
# 32. find plan for standard context
#
- expect { run_mutation }.not_to exceed_query_limit(32)
+ expect { run_mutation }.not_to exceed_query_limit(33)
end
end
@@ -101,30 +101,31 @@ RSpec.describe Mutations::DesignManagement::Delete do
# 30. find project by id (same query as 8)
- # 31. create event
- # 32. find plan for standard context
+ # 31. find project by id (same query as 8)
+ # 32. create event
+ # 33. find plan for standard context
#